# Collaborative work strategies when using HDP

> This is an early draft (Emerson Rocha, 2021-03-27 11:32)


- https://stackoverflow.com/questions/57168450/how-to-create-non-root-account-on-colab


## Jupyter Notebooks

- See https://jupyter.org/
- See https://jupyter.org/hub

## Google Colab


```bash
# Create an non-root user
!adduser humanitarian
!usermod -aG sudo humanitarian
```

